# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pulpcore.client.pulp_container
from pulpcore.client.pulp_container.api.repositories_container_api import RepositoriesContainerApi  # noqa: E501
from pulpcore.client.pulp_container.rest import ApiException


class TestRepositoriesContainerApi(unittest.TestCase):
    """RepositoriesContainerApi unit test stubs"""

    def setUp(self):
        self.api = pulpcore.client.pulp_container.api.repositories_container_api.RepositoriesContainerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add(self):
        """Test case for add

        Add content  # noqa: E501
        """
        pass

    def test_build_image(self):
        """Test case for build_image

        Build an Image  # noqa: E501
        """
        pass

    def test_copy_manifests(self):
        """Test case for copy_manifests

        Copy manifests  # noqa: E501
        """
        pass

    def test_copy_tags(self):
        """Test case for copy_tags

        Copy tags  # noqa: E501
        """
        pass

    def test_create(self):
        """Test case for create

        Create a container repository  # noqa: E501
        """
        pass

    def test_delete(self):
        """Test case for delete

        Delete a container repository  # noqa: E501
        """
        pass

    def test_list(self):
        """Test case for list

        List container repositorys  # noqa: E501
        """
        pass

    def test_partial_update(self):
        """Test case for partial_update

        Update a container repository  # noqa: E501
        """
        pass

    def test_read(self):
        """Test case for read

        Inspect a container repository  # noqa: E501
        """
        pass

    def test_remove(self):
        """Test case for remove

        Remove content  # noqa: E501
        """
        pass

    def test_sync(self):
        """Test case for sync

        Sync from a remote  # noqa: E501
        """
        pass

    def test_tag(self):
        """Test case for tag

        Create a Tag  # noqa: E501
        """
        pass

    def test_untag(self):
        """Test case for untag

        Delete a tag  # noqa: E501
        """
        pass

    def test_update(self):
        """Test case for update

        Update a container repository  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_container
from pulpcore.client.pulp_container.models.container_manifest_response import ContainerManifestResponse  # noqa: E501
from pulpcore.client.pulp_container.rest import ApiException

class TestContainerManifestResponse(unittest.TestCase):
    """ContainerManifestResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ContainerManifestResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_container.models.container_manifest_response.ContainerManifestResponse()  # noqa: E501
        if include_optional :
            return ContainerManifestResponse(
                pulp_href = '0', 
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                artifact = '0', 
                digest = '0', 
                schema_version = 56, 
                media_type = '0', 
                listed_manifests = [
                    '0'
                    ], 
                config_blob = '0', 
                blobs = [
                    '0'
                    ]
            )
        else :
            return ContainerManifestResponse(
                artifact = '0',
                digest = '0',
                schema_version = 56,
                media_type = '0',
                listed_manifests = [
                    '0'
                    ],
                blobs = [
                    '0'
                    ],
        )

    def testContainerManifestResponse(self):
        """Test ContainerManifestResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pulpcore.client.pulp_container.api_client import ApiClient
from pulpcore.client.pulp_container.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class RepositoriesContainerVersionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete(self, container_container_repository_version_href, **kwargs):  # noqa: E501
        """Delete a repository version  # noqa: E501

        Trigger an asynchronous task to delete a repository version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete(container_container_repository_version_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str container_container_repository_version_href: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AsyncOperationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_with_http_info(container_container_repository_version_href, **kwargs)  # noqa: E501

    def delete_with_http_info(self, container_container_repository_version_href, **kwargs):  # noqa: E501
        """Delete a repository version  # noqa: E501

        Trigger an asynchronous task to delete a repository version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_with_http_info(container_container_repository_version_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str container_container_repository_version_href: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AsyncOperationResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'container_container_repository_version_href'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'container_container_repository_version_href' is set
        if self.api_client.client_side_validation and ('container_container_repository_version_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['container_container_repository_version_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `container_container_repository_version_href` when calling `delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_container_repository_version_href' in local_var_params:
            path_params['container_container_repository_version_href'] = local_var_params['container_container_repository_version_href']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{container_container_repository_version_href}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AsyncOperationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list(self, container_container_repository_href, **kwargs):  # noqa: E501
        """List repository versions  # noqa: E501

        ContainerRepositoryVersion represents a single container repository version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list(container_container_repository_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str container_container_repository_href: (required)
        :param str content: Content Unit referenced by HREF
        :param str content__in: Content Unit referenced by HREF
        :param int limit: Number of results to return per page.
        :param int number:
        :param int number__gt: Filter results where number is greater than value
        :param int number__gte: Filter results where number is greater than or equal to value
        :param int number__lt: Filter results where number is less than value
        :param int number__lte: Filter results where number is less than or equal to value
        :param list[int] number__range: Filter results where number is between two comma separated values
        :param int offset: The initial index from which to return the results.
        :param str ordering: Which field to use when ordering the results.
        :param datetime pulp_created: ISO 8601 formatted dates are supported
        :param datetime pulp_created__gt: Filter results where pulp_created is greater than value
        :param datetime pulp_created__gte: Filter results where pulp_created is greater than or equal to value
        :param datetime pulp_created__lt: Filter results where pulp_created is less than value
        :param datetime pulp_created__lte: Filter results where pulp_created is less than or equal to value
        :param list[datetime] pulp_created__range: Filter results where pulp_created is between two comma separated values
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PaginatedRepositoryVersionResponseList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_with_http_info(container_container_repository_href, **kwargs)  # noqa: E501

    def list_with_http_info(self, container_container_repository_href, **kwargs):  # noqa: E501
        """List repository versions  # noqa: E501

        ContainerRepositoryVersion represents a single container repository version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_with_http_info(container_container_repository_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str container_container_repository_href: (required)
        :param str content: Content Unit referenced by HREF
        :param str content__in: Content Unit referenced by HREF
        :param int limit: Number of results to return per page.
        :param int number:
        :param int number__gt: Filter results where number is greater than value
        :param int number__gte: Filter results where number is greater than or equal to value
        :param int number__lt: Filter results where number is less than value
        :param int number__lte: Filter results where number is less than or equal to value
        :param list[int] number__range: Filter results where number is between two comma separated values
        :param int offset: The initial index from which to return the results.
        :param str ordering: Which field to use when ordering the results.
        :param datetime pulp_created: ISO 8601 formatted dates are supported
        :param datetime pulp_created__gt: Filter results where pulp_created is greater than value
        :param datetime pulp_created__gte: Filter results where pulp_created is greater than or equal to value
        :param datetime pulp_created__lt: Filter results where pulp_created is less than value
        :param datetime pulp_created__lte: Filter results where pulp_created is less than or equal to value
        :param list[datetime] pulp_created__range: Filter results where pulp_created is between two comma separated values
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PaginatedRepositoryVersionResponseList, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'container_container_repository_href',
            'content',
            'content__in',
            'limit',
            'number',
            'number__gt',
            'number__gte',
            'number__lt',
            'number__lte',
            'number__range',
            'offset',
            'ordering',
            'pulp_created',
            'pulp_created__gt',
            'pulp_created__gte',
            'pulp_created__lt',
            'pulp_created__lte',
            'pulp_created__range',
            'fields',
            'exclude_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'container_container_repository_href' is set
        if self.api_client.client_side_validation and ('container_container_repository_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['container_container_repository_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `container_container_repository_href` when calling `list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_container_repository_href' in local_var_params:
            path_params['container_container_repository_href'] = local_var_params['container_container_repository_href']  # noqa: E501

        query_params = []
        if 'content' in local_var_params and local_var_params['content'] is not None:  # noqa: E501
            query_params.append(('content', local_var_params['content']))  # noqa: E501
        if 'content__in' in local_var_params and local_var_params['content__in'] is not None:  # noqa: E501
            query_params.append(('content__in', local_var_params['content__in']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'number' in local_var_params and local_var_params['number'] is not None:  # noqa: E501
            query_params.append(('number', local_var_params['number']))  # noqa: E501
        if 'number__gt' in local_var_params and local_var_params['number__gt'] is not None:  # noqa: E501
            query_params.append(('number__gt', local_var_params['number__gt']))  # noqa: E501
        if 'number__gte' in local_var_params and local_var_params['number__gte'] is not None:  # noqa: E501
            query_params.append(('number__gte', local_var_params['number__gte']))  # noqa: E501
        if 'number__lt' in local_var_params and local_var_params['number__lt'] is not None:  # noqa: E501
            query_params.append(('number__lt', local_var_params['number__lt']))  # noqa: E501
        if 'number__lte' in local_var_params and local_var_params['number__lte'] is not None:  # noqa: E501
            query_params.append(('number__lte', local_var_params['number__lte']))  # noqa: E501
        if 'number__range' in local_var_params and local_var_params['number__range'] is not None:  # noqa: E501
            query_params.append(('number__range', local_var_params['number__range']))  # noqa: E501
            collection_formats['number__range'] = 'csv'  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'ordering' in local_var_params and local_var_params['ordering'] is not None:  # noqa: E501
            query_params.append(('ordering', local_var_params['ordering']))  # noqa: E501
        if 'pulp_created' in local_var_params and local_var_params['pulp_created'] is not None:  # noqa: E501
            query_params.append(('pulp_created', local_var_params['pulp_created']))  # noqa: E501
        if 'pulp_created__gt' in local_var_params and local_var_params['pulp_created__gt'] is not None:  # noqa: E501
            query_params.append(('pulp_created__gt', local_var_params['pulp_created__gt']))  # noqa: E501
        if 'pulp_created__gte' in local_var_params and local_var_params['pulp_created__gte'] is not None:  # noqa: E501
            query_params.append(('pulp_created__gte', local_var_params['pulp_created__gte']))  # noqa: E501
        if 'pulp_created__lt' in local_var_params and local_var_params['pulp_created__lt'] is not None:  # noqa: E501
            query_params.append(('pulp_created__lt', local_var_params['pulp_created__lt']))  # noqa: E501
        if 'pulp_created__lte' in local_var_params and local_var_params['pulp_created__lte'] is not None:  # noqa: E501
            query_params.append(('pulp_created__lte', local_var_params['pulp_created__lte']))  # noqa: E501
        if 'pulp_created__range' in local_var_params and local_var_params['pulp_created__range'] is not None:  # noqa: E501
            query_params.append(('pulp_created__range', local_var_params['pulp_created__range']))  # noqa: E501
            collection_formats['pulp_created__range'] = 'csv'  # noqa: E501
        if 'fields' in local_var_params and local_var_params['fields'] is not None:  # noqa: E501
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501
        if 'exclude_fields' in local_var_params and local_var_params['exclude_fields'] is not None:  # noqa: E501
            query_params.append(('exclude_fields', local_var_params['exclude_fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{container_container_repository_href}versions/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PaginatedRepositoryVersionResponseList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def read(self, container_container_repository_version_href, **kwargs):  # noqa: E501
        """Inspect a repository version  # noqa: E501

        ContainerRepositoryVersion represents a single container repository version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read(container_container_repository_version_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str container_container_repository_version_href: (required)
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RepositoryVersionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.read_with_http_info(container_container_repository_version_href, **kwargs)  # noqa: E501

    def read_with_http_info(self, container_container_repository_version_href, **kwargs):  # noqa: E501
        """Inspect a repository version  # noqa: E501

        ContainerRepositoryVersion represents a single container repository version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_with_http_info(container_container_repository_version_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str container_container_repository_version_href: (required)
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RepositoryVersionResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'container_container_repository_version_href',
            'fields',
            'exclude_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'container_container_repository_version_href' is set
        if self.api_client.client_side_validation and ('container_container_repository_version_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['container_container_repository_version_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `container_container_repository_version_href` when calling `read`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_container_repository_version_href' in local_var_params:
            path_params['container_container_repository_version_href'] = local_var_params['container_container_repository_version_href']  # noqa: E501

        query_params = []
        if 'fields' in local_var_params and local_var_params['fields'] is not None:  # noqa: E501
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501
        if 'exclude_fields' in local_var_params and local_var_params['exclude_fields'] is not None:  # noqa: E501
            query_params.append(('exclude_fields', local_var_params['exclude_fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{container_container_repository_version_href}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RepositoryVersionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def repair(self, container_container_repository_version_href, repository_version, **kwargs):  # noqa: E501
        """repair  # noqa: E501

        Trigger an asynchronous task to repair a repository version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.repair(container_container_repository_version_href, repository_version, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str container_container_repository_version_href: (required)
        :param RepositoryVersion repository_version: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AsyncOperationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.repair_with_http_info(container_container_repository_version_href, repository_version, **kwargs)  # noqa: E501

    def repair_with_http_info(self, container_container_repository_version_href, repository_version, **kwargs):  # noqa: E501
        """repair  # noqa: E501

        Trigger an asynchronous task to repair a repository version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.repair_with_http_info(container_container_repository_version_href, repository_version, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str container_container_repository_version_href: (required)
        :param RepositoryVersion repository_version: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AsyncOperationResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'container_container_repository_version_href',
            'repository_version'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method repair" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'container_container_repository_version_href' is set
        if self.api_client.client_side_validation and ('container_container_repository_version_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['container_container_repository_version_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `container_container_repository_version_href` when calling `repair`")  # noqa: E501
        # verify the required parameter 'repository_version' is set
        if self.api_client.client_side_validation and ('repository_version' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_version'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_version` when calling `repair`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_container_repository_version_href' in local_var_params:
            path_params['container_container_repository_version_href'] = local_var_params['container_container_repository_version_href']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'repository_version' in local_var_params:
            body_params = local_var_params['repository_version']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{container_container_repository_version_href}repair/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AsyncOperationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_container.configuration import Configuration


class ManifestCopy(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'source_repository': 'str',
        'source_repository_version': 'str',
        'digests': 'list[object]',
        'media_types': 'list[MediaTypesEnum]'
    }

    attribute_map = {
        'source_repository': 'source_repository',
        'source_repository_version': 'source_repository_version',
        'digests': 'digests',
        'media_types': 'media_types'
    }

    def __init__(self, source_repository=None, source_repository_version=None, digests=None, media_types=None, local_vars_configuration=None):  # noqa: E501
        """ManifestCopy - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._source_repository = None
        self._source_repository_version = None
        self._digests = None
        self._media_types = None
        self.discriminator = None

        if source_repository is not None:
            self.source_repository = source_repository
        if source_repository_version is not None:
            self.source_repository_version = source_repository_version
        if digests is not None:
            self.digests = digests
        if media_types is not None:
            self.media_types = media_types

    @property
    def source_repository(self):
        """Gets the source_repository of this ManifestCopy.  # noqa: E501

        A URI of the repository to copy content from.  # noqa: E501

        :return: The source_repository of this ManifestCopy.  # noqa: E501
        :rtype: str
        """
        return self._source_repository

    @source_repository.setter
    def source_repository(self, source_repository):
        """Sets the source_repository of this ManifestCopy.

        A URI of the repository to copy content from.  # noqa: E501

        :param source_repository: The source_repository of this ManifestCopy.  # noqa: E501
        :type: str
        """

        self._source_repository = source_repository

    @property
    def source_repository_version(self):
        """Gets the source_repository_version of this ManifestCopy.  # noqa: E501

        A URI of the repository version to copy content from.  # noqa: E501

        :return: The source_repository_version of this ManifestCopy.  # noqa: E501
        :rtype: str
        """
        return self._source_repository_version

    @source_repository_version.setter
    def source_repository_version(self, source_repository_version):
        """Sets the source_repository_version of this ManifestCopy.

        A URI of the repository version to copy content from.  # noqa: E501

        :param source_repository_version: The source_repository_version of this ManifestCopy.  # noqa: E501
        :type: str
        """

        self._source_repository_version = source_repository_version

    @property
    def digests(self):
        """Gets the digests of this ManifestCopy.  # noqa: E501

        A list of manifest digests to copy.  # noqa: E501

        :return: The digests of this ManifestCopy.  # noqa: E501
        :rtype: list[object]
        """
        return self._digests

    @digests.setter
    def digests(self, digests):
        """Sets the digests of this ManifestCopy.

        A list of manifest digests to copy.  # noqa: E501

        :param digests: The digests of this ManifestCopy.  # noqa: E501
        :type: list[object]
        """

        self._digests = digests

    @property
    def media_types(self):
        """Gets the media_types of this ManifestCopy.  # noqa: E501

        A list of media_types to copy.  # noqa: E501

        :return: The media_types of this ManifestCopy.  # noqa: E501
        :rtype: list[MediaTypesEnum]
        """
        return self._media_types

    @media_types.setter
    def media_types(self, media_types):
        """Sets the media_types of this ManifestCopy.

        A list of media_types to copy.  # noqa: E501

        :param media_types: The media_types of this ManifestCopy.  # noqa: E501
        :type: list[MediaTypesEnum]
        """

        self._media_types = media_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ManifestCopy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ManifestCopy):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "2.8.2"

# import apis into sdk package
from pulpcore.client.pulp_container.api.content_blobs_api import ContentBlobsApi
from pulpcore.client.pulp_container.api.content_manifests_api import ContentManifestsApi
from pulpcore.client.pulp_container.api.content_tags_api import ContentTagsApi
from pulpcore.client.pulp_container.api.contentguards_content_redirect_api import ContentguardsContentRedirectApi
from pulpcore.client.pulp_container.api.distributions_container_api import DistributionsContainerApi
from pulpcore.client.pulp_container.api.pulp_container_namespaces_api import PulpContainerNamespacesApi
from pulpcore.client.pulp_container.api.remotes_container_api import RemotesContainerApi
from pulpcore.client.pulp_container.api.repositories_container_api import RepositoriesContainerApi
from pulpcore.client.pulp_container.api.repositories_container_push_api import RepositoriesContainerPushApi
from pulpcore.client.pulp_container.api.repositories_container_push_versions_api import RepositoriesContainerPushVersionsApi
from pulpcore.client.pulp_container.api.repositories_container_versions_api import RepositoriesContainerVersionsApi
from pulpcore.client.pulp_container.api.token_api import TokenApi

# import ApiClient
from pulpcore.client.pulp_container.api_client import ApiClient
from pulpcore.client.pulp_container.configuration import Configuration
from pulpcore.client.pulp_container.exceptions import OpenApiException
from pulpcore.client.pulp_container.exceptions import ApiTypeError
from pulpcore.client.pulp_container.exceptions import ApiValueError
from pulpcore.client.pulp_container.exceptions import ApiKeyError
from pulpcore.client.pulp_container.exceptions import ApiException
# import models into sdk package
from pulpcore.client.pulp_container.models.async_operation_response import AsyncOperationResponse
from pulpcore.client.pulp_container.models.container_blob_response import ContainerBlobResponse
from pulpcore.client.pulp_container.models.container_container_distribution import ContainerContainerDistribution
from pulpcore.client.pulp_container.models.container_container_distribution_response import ContainerContainerDistributionResponse
from pulpcore.client.pulp_container.models.container_container_namespace import ContainerContainerNamespace
from pulpcore.client.pulp_container.models.container_container_namespace_response import ContainerContainerNamespaceResponse
from pulpcore.client.pulp_container.models.container_container_push_repository import ContainerContainerPushRepository
from pulpcore.client.pulp_container.models.container_container_push_repository_response import ContainerContainerPushRepositoryResponse
from pulpcore.client.pulp_container.models.container_container_remote import ContainerContainerRemote
from pulpcore.client.pulp_container.models.container_container_remote_response import ContainerContainerRemoteResponse
from pulpcore.client.pulp_container.models.container_container_repository import ContainerContainerRepository
from pulpcore.client.pulp_container.models.container_container_repository_response import ContainerContainerRepositoryResponse
from pulpcore.client.pulp_container.models.container_content_redirect_content_guard import ContainerContentRedirectContentGuard
from pulpcore.client.pulp_container.models.container_content_redirect_content_guard_response import ContainerContentRedirectContentGuardResponse
from pulpcore.client.pulp_container.models.container_manifest_response import ContainerManifestResponse
from pulpcore.client.pulp_container.models.container_tag_response import ContainerTagResponse
from pulpcore.client.pulp_container.models.content_summary import ContentSummary
from pulpcore.client.pulp_container.models.content_summary_response import ContentSummaryResponse
from pulpcore.client.pulp_container.models.manifest_copy import ManifestCopy
from pulpcore.client.pulp_container.models.media_types_enum import MediaTypesEnum
from pulpcore.client.pulp_container.models.oci_build_image import OCIBuildImage
from pulpcore.client.pulp_container.models.paginated_repository_version_response_list import PaginatedRepositoryVersionResponseList
from pulpcore.client.pulp_container.models.paginatedcontainer_blob_response_list import PaginatedcontainerBlobResponseList
from pulpcore.client.pulp_container.models.paginatedcontainer_container_distribution_response_list import PaginatedcontainerContainerDistributionResponseList
from pulpcore.client.pulp_container.models.paginatedcontainer_container_namespace_response_list import PaginatedcontainerContainerNamespaceResponseList
from pulpcore.client.pulp_container.models.paginatedcontainer_container_push_repository_response_list import PaginatedcontainerContainerPushRepositoryResponseList
from pulpcore.client.pulp_container.models.paginatedcontainer_container_remote_response_list import PaginatedcontainerContainerRemoteResponseList
from pulpcore.client.pulp_container.models.paginatedcontainer_container_repository_response_list import PaginatedcontainerContainerRepositoryResponseList
from pulpcore.client.pulp_container.models.paginatedcontainer_content_redirect_content_guard_response_list import PaginatedcontainerContentRedirectContentGuardResponseList
from pulpcore.client.pulp_container.models.paginatedcontainer_manifest_response_list import PaginatedcontainerManifestResponseList
from pulpcore.client.pulp_container.models.paginatedcontainer_tag_response_list import PaginatedcontainerTagResponseList
from pulpcore.client.pulp_container.models.patchedcontainer_container_distribution import PatchedcontainerContainerDistribution
from pulpcore.client.pulp_container.models.patchedcontainer_container_push_repository import PatchedcontainerContainerPushRepository
from pulpcore.client.pulp_container.models.patchedcontainer_container_remote import PatchedcontainerContainerRemote
from pulpcore.client.pulp_container.models.patchedcontainer_container_repository import PatchedcontainerContainerRepository
from pulpcore.client.pulp_container.models.patchedcontainer_content_redirect_content_guard import PatchedcontainerContentRedirectContentGuard
from pulpcore.client.pulp_container.models.policy_enum import PolicyEnum
from pulpcore.client.pulp_container.models.recursive_manage import RecursiveManage
from pulpcore.client.pulp_container.models.remove_image import RemoveImage
from pulpcore.client.pulp_container.models.repository_sync_url import RepositorySyncURL
from pulpcore.client.pulp_container.models.repository_version import RepositoryVersion
from pulpcore.client.pulp_container.models.repository_version_response import RepositoryVersionResponse
from pulpcore.client.pulp_container.models.tag_copy import TagCopy
from pulpcore.client.pulp_container.models.tag_image import TagImage
from pulpcore.client.pulp_container.models.un_tag_image import UnTagImage




from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from pulpcore.client.pulp_container.api.content_blobs_api import ContentBlobsApi
from pulpcore.client.pulp_container.api.content_manifests_api import ContentManifestsApi
from pulpcore.client.pulp_container.api.content_tags_api import ContentTagsApi
from pulpcore.client.pulp_container.api.contentguards_content_redirect_api import ContentguardsContentRedirectApi
from pulpcore.client.pulp_container.api.distributions_container_api import DistributionsContainerApi
from pulpcore.client.pulp_container.api.pulp_container_namespaces_api import PulpContainerNamespacesApi
from pulpcore.client.pulp_container.api.remotes_container_api import RemotesContainerApi
from pulpcore.client.pulp_container.api.repositories_container_api import RepositoriesContainerApi
from pulpcore.client.pulp_container.api.repositories_container_push_api import RepositoriesContainerPushApi
from pulpcore.client.pulp_container.api.repositories_container_push_versions_api import RepositoriesContainerPushVersionsApi
from pulpcore.client.pulp_container.api.repositories_container_versions_api import RepositoriesContainerVersionsApi
from pulpcore.client.pulp_container.api.token_api import TokenApi



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pulpcore.client.pulp_container
from pulpcore.client.pulp_container.api.distributions_container_api import DistributionsContainerApi  # noqa: E501
from pulpcore.client.pulp_container.rest import ApiException


class TestDistributionsContainerApi(unittest.TestCase):
    """DistributionsContainerApi unit test stubs"""

    def setUp(self):
        self.api = pulpcore.client.pulp_container.api.distributions_container_api.DistributionsContainerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create(self):
        """Test case for create

        Create a container distribution  # noqa: E501
        """
        pass

    def test_delete(self):
        """Test case for delete

        Delete a container distribution  # noqa: E501
        """
        pass

    def test_list(self):
        """Test case for list

        List container distributions  # noqa: E501
        """
        pass

    def test_partial_update(self):
        """Test case for partial_update

        Update a container distribution  # noqa: E501
        """
        pass

    def test_read(self):
        """Test case for read

        Inspect a container distribution  # noqa: E501
        """
        pass

    def test_update(self):
        """Test case for update

        Update a container distribution  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_container.configuration import Configuration


class OCIBuildImage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'containerfile_artifact': 'str',
        'containerfile': 'file',
        'tag': 'str',
        'artifacts': 'object'
    }

    attribute_map = {
        'containerfile_artifact': 'containerfile_artifact',
        'containerfile': 'containerfile',
        'tag': 'tag',
        'artifacts': 'artifacts'
    }

    def __init__(self, containerfile_artifact=None, containerfile=None, tag='latest', artifacts=None, local_vars_configuration=None):  # noqa: E501
        """OCIBuildImage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._containerfile_artifact = None
        self._containerfile = None
        self._tag = None
        self._artifacts = None
        self.discriminator = None

        if containerfile_artifact is not None:
            self.containerfile_artifact = containerfile_artifact
        if containerfile is not None:
            self.containerfile = containerfile
        if tag is not None:
            self.tag = tag
        if artifacts is not None:
            self.artifacts = artifacts

    @property
    def containerfile_artifact(self):
        """Gets the containerfile_artifact of this OCIBuildImage.  # noqa: E501

        Artifact representing the Containerfile that should be used to run buildah.  # noqa: E501

        :return: The containerfile_artifact of this OCIBuildImage.  # noqa: E501
        :rtype: str
        """
        return self._containerfile_artifact

    @containerfile_artifact.setter
    def containerfile_artifact(self, containerfile_artifact):
        """Sets the containerfile_artifact of this OCIBuildImage.

        Artifact representing the Containerfile that should be used to run buildah.  # noqa: E501

        :param containerfile_artifact: The containerfile_artifact of this OCIBuildImage.  # noqa: E501
        :type: str
        """

        self._containerfile_artifact = containerfile_artifact

    @property
    def containerfile(self):
        """Gets the containerfile of this OCIBuildImage.  # noqa: E501

        An uploaded Containerfile that should be used to run buildah.  # noqa: E501

        :return: The containerfile of this OCIBuildImage.  # noqa: E501
        :rtype: file
        """
        return self._containerfile

    @containerfile.setter
    def containerfile(self, containerfile):
        """Sets the containerfile of this OCIBuildImage.

        An uploaded Containerfile that should be used to run buildah.  # noqa: E501

        :param containerfile: The containerfile of this OCIBuildImage.  # noqa: E501
        :type: file
        """

        self._containerfile = containerfile

    @property
    def tag(self):
        """Gets the tag of this OCIBuildImage.  # noqa: E501

        A tag name for the new image being built.  # noqa: E501

        :return: The tag of this OCIBuildImage.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this OCIBuildImage.

        A tag name for the new image being built.  # noqa: E501

        :param tag: The tag of this OCIBuildImage.  # noqa: E501
        :type: str
        """

        self._tag = tag

    @property
    def artifacts(self):
        """Gets the artifacts of this OCIBuildImage.  # noqa: E501

        A JSON string where each key is an artifact href and the value is it's relative path (name) inside the /pulp_working_directory of the build container executing the Containerfile.  # noqa: E501

        :return: The artifacts of this OCIBuildImage.  # noqa: E501
        :rtype: object
        """
        return self._artifacts

    @artifacts.setter
    def artifacts(self, artifacts):
        """Sets the artifacts of this OCIBuildImage.

        A JSON string where each key is an artifact href and the value is it's relative path (name) inside the /pulp_working_directory of the build container executing the Containerfile.  # noqa: E501

        :param artifacts: The artifacts of this OCIBuildImage.  # noqa: E501
        :type: object
        """

        self._artifacts = artifacts

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OCIBuildImage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OCIBuildImage):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_container.configuration import Configuration


class ContainerManifestResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'artifact': 'str',
        'digest': 'str',
        'schema_version': 'int',
        'media_type': 'str',
        'listed_manifests': 'list[str]',
        'config_blob': 'str',
        'blobs': 'list[str]'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'artifact': 'artifact',
        'digest': 'digest',
        'schema_version': 'schema_version',
        'media_type': 'media_type',
        'listed_manifests': 'listed_manifests',
        'config_blob': 'config_blob',
        'blobs': 'blobs'
    }

    def __init__(self, pulp_href=None, pulp_created=None, artifact=None, digest=None, schema_version=None, media_type=None, listed_manifests=None, config_blob=None, blobs=None, local_vars_configuration=None):  # noqa: E501
        """ContainerManifestResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._pulp_created = None
        self._artifact = None
        self._digest = None
        self._schema_version = None
        self._media_type = None
        self._listed_manifests = None
        self._config_blob = None
        self._blobs = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        self.artifact = artifact
        self.digest = digest
        self.schema_version = schema_version
        self.media_type = media_type
        self.listed_manifests = listed_manifests
        if config_blob is not None:
            self.config_blob = config_blob
        self.blobs = blobs

    @property
    def pulp_href(self):
        """Gets the pulp_href of this ContainerManifestResponse.  # noqa: E501


        :return: The pulp_href of this ContainerManifestResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this ContainerManifestResponse.


        :param pulp_href: The pulp_href of this ContainerManifestResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this ContainerManifestResponse.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this ContainerManifestResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this ContainerManifestResponse.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this ContainerManifestResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def artifact(self):
        """Gets the artifact of this ContainerManifestResponse.  # noqa: E501

        Artifact file representing the physical content  # noqa: E501

        :return: The artifact of this ContainerManifestResponse.  # noqa: E501
        :rtype: str
        """
        return self._artifact

    @artifact.setter
    def artifact(self, artifact):
        """Sets the artifact of this ContainerManifestResponse.

        Artifact file representing the physical content  # noqa: E501

        :param artifact: The artifact of this ContainerManifestResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and artifact is None:  # noqa: E501
            raise ValueError("Invalid value for `artifact`, must not be `None`")  # noqa: E501

        self._artifact = artifact

    @property
    def digest(self):
        """Gets the digest of this ContainerManifestResponse.  # noqa: E501

        sha256 of the Manifest file  # noqa: E501

        :return: The digest of this ContainerManifestResponse.  # noqa: E501
        :rtype: str
        """
        return self._digest

    @digest.setter
    def digest(self, digest):
        """Sets the digest of this ContainerManifestResponse.

        sha256 of the Manifest file  # noqa: E501

        :param digest: The digest of this ContainerManifestResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and digest is None:  # noqa: E501
            raise ValueError("Invalid value for `digest`, must not be `None`")  # noqa: E501

        self._digest = digest

    @property
    def schema_version(self):
        """Gets the schema_version of this ContainerManifestResponse.  # noqa: E501

        Manifest schema version  # noqa: E501

        :return: The schema_version of this ContainerManifestResponse.  # noqa: E501
        :rtype: int
        """
        return self._schema_version

    @schema_version.setter
    def schema_version(self, schema_version):
        """Sets the schema_version of this ContainerManifestResponse.

        Manifest schema version  # noqa: E501

        :param schema_version: The schema_version of this ContainerManifestResponse.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and schema_version is None:  # noqa: E501
            raise ValueError("Invalid value for `schema_version`, must not be `None`")  # noqa: E501

        self._schema_version = schema_version

    @property
    def media_type(self):
        """Gets the media_type of this ContainerManifestResponse.  # noqa: E501

        Manifest media type of the file  # noqa: E501

        :return: The media_type of this ContainerManifestResponse.  # noqa: E501
        :rtype: str
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """Sets the media_type of this ContainerManifestResponse.

        Manifest media type of the file  # noqa: E501

        :param media_type: The media_type of this ContainerManifestResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and media_type is None:  # noqa: E501
            raise ValueError("Invalid value for `media_type`, must not be `None`")  # noqa: E501

        self._media_type = media_type

    @property
    def listed_manifests(self):
        """Gets the listed_manifests of this ContainerManifestResponse.  # noqa: E501

        Manifests that are referenced by this Manifest List  # noqa: E501

        :return: The listed_manifests of this ContainerManifestResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._listed_manifests

    @listed_manifests.setter
    def listed_manifests(self, listed_manifests):
        """Sets the listed_manifests of this ContainerManifestResponse.

        Manifests that are referenced by this Manifest List  # noqa: E501

        :param listed_manifests: The listed_manifests of this ContainerManifestResponse.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and listed_manifests is None:  # noqa: E501
            raise ValueError("Invalid value for `listed_manifests`, must not be `None`")  # noqa: E501

        self._listed_manifests = listed_manifests

    @property
    def config_blob(self):
        """Gets the config_blob of this ContainerManifestResponse.  # noqa: E501

        Blob that contains configuration for this Manifest  # noqa: E501

        :return: The config_blob of this ContainerManifestResponse.  # noqa: E501
        :rtype: str
        """
        return self._config_blob

    @config_blob.setter
    def config_blob(self, config_blob):
        """Sets the config_blob of this ContainerManifestResponse.

        Blob that contains configuration for this Manifest  # noqa: E501

        :param config_blob: The config_blob of this ContainerManifestResponse.  # noqa: E501
        :type: str
        """

        self._config_blob = config_blob

    @property
    def blobs(self):
        """Gets the blobs of this ContainerManifestResponse.  # noqa: E501

        Blobs that are referenced by this Manifest  # noqa: E501

        :return: The blobs of this ContainerManifestResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._blobs

    @blobs.setter
    def blobs(self, blobs):
        """Sets the blobs of this ContainerManifestResponse.

        Blobs that are referenced by this Manifest  # noqa: E501

        :param blobs: The blobs of this ContainerManifestResponse.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and blobs is None:  # noqa: E501
            raise ValueError("Invalid value for `blobs`, must not be `None`")  # noqa: E501

        self._blobs = blobs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContainerManifestResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ContainerManifestResponse):
            return True

        return self.to_dict() != other.to_dict()
